# DiffValueChangeBoolean


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**new_value** | **bool** |  | [optional] 
**old_value** | **bool** |  | [optional] 

## Example

```python
from src.client.generated.models.diff_value_change_boolean import DiffValueChangeBoolean

# TODO update the JSON string below
json = "{}"
# create an instance of DiffValueChangeBoolean from a JSON string
diff_value_change_boolean_instance = DiffValueChangeBoolean.from_json(json)
# print the JSON string representation of the object
print(DiffValueChangeBoolean.to_json())

# convert the object into a dict
diff_value_change_boolean_dict = diff_value_change_boolean_instance.to_dict()
# create an instance of DiffValueChangeBoolean from a dict
diff_value_change_boolean_from_dict = DiffValueChangeBoolean.from_dict(diff_value_change_boolean_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


